summaryrefslogtreecommitdiffstats
path: root/include/helper.h
diff options
context:
space:
mode:
authorDave Davenport <qball@gmpclient.org>2017-06-09 09:18:17 +0200
committerDave Davenport <qball@gmpclient.org>2017-06-09 09:18:17 +0200
commit067544120f950039557a04f1ba06ec6870bd1088 (patch)
tree4b4eb49b9f63587ce3e4ab7e3e39847f30e61327 /include/helper.h
parentb99f86f34195cefe0bcb287f2f5b4469a83d03c9 (diff)
Make function declaration match function prototype.
- Extra NULL check.
Diffstat (limited to 'include/helper.h')
-rw-r--r--include/helper.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/helper.h b/include/helper.h
index 55cf855f..ad7359fb 100644
--- a/include/helper.h
+++ b/include/helper.h
@@ -225,13 +225,13 @@ char * rofi_force_utf8 ( const gchar *data, ssize_t length );
char * rofi_latin_to_utf8_strdup ( const char *input, gssize length );
/**
* @param input the string to escape
*
* Escape XML markup from the string. @param input is freed.
*
* @return the escaped string
*/
-gchar *rofi_escape_markup ( gchar *input );
+gchar *rofi_escape_markup ( gchar *text );
/**
* @param pattern The user input to match against.
@@ -225,13 +225,13 @@ char * rofi_force_utf8 ( const gchar *data, ssize_t length );
char * rofi_latin_to_utf8_strdup ( const char *input, gssize length );
/**
- * @param input the string to escape
+ * @param text the string to escape
*
* Escape XML markup from the string. @param input is freed.